@@ -356,7 +356,7 @@ public class ProxyConfigurationResourceDefinition extends ChildResourceDefinitio
                 .addCapabilities(Capability.class)
                 ;
 
-        registration.registerReadWriteAttribute(Attribute.SSL_CONTEXT.getDefinition(), null, new ReloadRequiredWriteAttributeHandler() {
+        registration.registerReadWriteAttribute(Attribute.SSL_CONTEXT.getDefinition(), null, new ReloadRequiredWriteAttributeHandler(Attribute.SSL_CONTEXT.getDefinition()) {
             @Override
             protected void validateUpdatedModel(OperationContext context, Resource model) {
                 context.addStep(new OperationStepHandler() {
